@@ -1,15 +1,10 @@
 import sys
 
+from sqlalchemy.testing import exclusions
+from sqlalchemy.testing.requirements import Requirements
+
 from alembic import util
 from alembic.util import sqla_compat
-from . import exclusions
-
-if util.sqla_094:
-    from sqlalchemy.testing.requirements import Requirements
-else:
-
-    class Requirements(object):
-        pass
 
 
 class SuiteRequirements(Requirements):
@@ -20,6 +15,12 @@ class SuiteRequirements(Requirements):
 
         return exclusions.open()
 
+    @property
+    def autocommit_isolation(self):
+        """target database should support 'AUTOCOMMIT' isolation level"""
+
+        return exclusions.closed()
+
     @property
     def unique_constraint_reflection(self):
         def doesnt_have_check_uq_constraints(config):
@@ -62,66 +63,25 @@ class SuiteRequirements(Requirements):
         return exclusions.closed()
 
     @property
-    def fail_before_sqla_100(self):
-        return exclusions.fails_if(
-            lambda config: not util.sqla_100,
-            "SQLAlchemy 1.0.0 or greater required",
-        )
-
-    @property
-    def fail_before_sqla_1010(self):
-        return exclusions.fails_if(
-            lambda config: not util.sqla_1010,
-            "SQLAlchemy 1.0.10 or greater required",
-        )
-
-    @property
-    def fail_before_sqla_099(self):
-        return exclusions.fails_if(
-            lambda config: not util.sqla_099,
-            "SQLAlchemy 0.9.9 or greater required",
-        )
-
-    @property
-    def fail_before_sqla_110(self):
-        return exclusions.fails_if(
-            lambda config: not util.sqla_110,
-            "SQLAlchemy 1.1.0 or greater required",
-        )
-
-    @property
-    def sqlalchemy_092(self):
+    def sqlalchemy_issue_3740(self):
+        """Fixes percent sign escaping for paramstyles that don't require it"""
         return exclusions.skip_if(
-            lambda config: not util.sqla_092,
-            "SQLAlchemy 0.9.2 or greater required",
+            lambda config: not util.sqla_120,
+            "SQLAlchemy 1.2 or greater required",
         )
 
     @property
-    def sqlalchemy_094(self):
+    def sqlalchemy_12(self):
         return exclusions.skip_if(
-            lambda config: not util.sqla_094,
-            "SQLAlchemy 0.9.4 or greater required",
+            lambda config: not util.sqla_1216,
+            "SQLAlchemy 1.2.16 or greater required",
         )
 
     @property
-    def sqlalchemy_099(self):
+    def sqlalchemy_13(self):
         return exclusions.skip_if(
-            lambda config: not util.sqla_099,
-            "SQLAlchemy 0.9.9 or greater required",
-        )
-
-    @property
-    def sqlalchemy_100(self):
-        return exclusions.skip_if(
-            lambda config: not util.sqla_100,
-            "SQLAlchemy 1.0.0 or greater required",
-        )
-
-    @property
-    def sqlalchemy_1014(self):
-        return exclusions.skip_if(
-            lambda config: not util.sqla_1014,
-            "SQLAlchemy 1.0.14 or greater required",
+            lambda config: not util.sqla_13,
+            "SQLAlchemy 1.3 or greater required",
         )
 
     @property
@@ -143,7 +103,7 @@ class SuiteRequirements(Requirements):
         def check(config):
             vers = sqla_compat._vers
 
-            if vers == (1, 3, 0, 'b1'):
+            if vers == (1, 3, 0, "b1"):
                 return True
             elif vers >= (1, 2, 16):
                 return False
@@ -151,8 +111,7 @@ class SuiteRequirements(Requirements):
                 return True
 
         return exclusions.skip_if(
-            check,
-            "SQLAlchemy 1.2.16, 1.3.0b2 or greater required",
+            check, "SQLAlchemy 1.2.16, 1.3.0b2 or greater required"
         )
 
     @property
@@ -177,3 +136,7 @@ class SuiteRequirements(Requirements):
     @property
     def comments_api(self):
         return exclusions.only_if(lambda config: util.sqla_120)
+
+    @property
+    def alter_column(self):
+        return exclusions.open()
